@@ -268,9 +268,9 @@ class Firefox:
     def find_by(
         self,
         type_: Optional[str] = None, #div, a, span, ...
+        attributes: Optional[Dict[str, str]] = None,
         id_: Optional[str] = None,
         class_: Optional[str] = None,
-        attributes: Optional[Dict[str, str]] = None,
         in_element: Optional = None,
         timeout: int = 15
     ) -> Optional:
@@ -303,9 +303,9 @@ class Firefox:
     def find_all_by(
         self,
         type_: Optional[str] = None, #div, a, span, ...
+        attributes: Optional[Dict[str, str]] = None,
         id_: Optional[str] = None,
         class_: Optional[str] = None,
-        attributes: Optional[Dict[str, str]] = None,
         in_element: Optional = None,
         timeout: int = 15
     ) -> Optional:
@@ -338,6 +338,13 @@ class Firefox:
             return None
 
     def save_cookies(self) -> None:
+        cookies_path = self.__cookies_path()
+
+        try:
+            os.remove(cookies_path)
+        except:
+            pass
+
         pickle.dump(
             self.driver.get_cookies(),
             open(self.__cookies_path(), "wb")
